==> activity-center-api-1.0.0-20160607.031653-2-sources.jar: cn/com/duiba/activity/center/api/remoteservice/RemoteActivityCategoryBackendService.java <==
/**
 * Project Name:activity-center-api
 * File Name:RemoteActivityCategoryBackendService.java
 * Package Name:cn.com.duiba.activity.center.api.remoteservice
 * Date:2016年6月7日上午8:52:18
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.api.remoteservice;

import java.util.List;

import cn.com.duiba.activity.center.api.dto.ActivityCategoryDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteActivityCategoryBackendService <br/>
 * Function: 活动类目管理的后台接口 <br/>
 * Date:     2016年6月7日 上午8:52:18 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface RemoteActivityCategoryBackendService {
    /**
     * 创建一个活动分类
     *
     * @author xuhengfei
     * @param name
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> createCategory(String name);
    /**
     * 修改活动分类的皮肤
     *
     * @author xuhengfei
     * @param id
     * @param content
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> editCategoryContent(long id,String content);
    /**
     * 启用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> enableCategory(long id);
    /**
     * 禁用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> disableCategory(long id);
    /**
     * 查询所有的活动分类
     *
     * @author xuhengfei
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<ActivityCategoryDto>> findAll();
}

==> activity-center-api-1.0.0-20160612.064711-7-sources.jar: cn/com/duiba/activity/center/api/remoteservice/RemoteActivityCategoryBackendService.java <==
/**
 * Project Name:activity-center-api
 * File Name:RemoteActivityCategoryBackendService.java
 * Package Name:cn.com.duiba.activity.center.api.remoteservice
 * Date:2016年6月7日上午8:52:18
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.api.remoteservice;

import java.util.List;

import cn.com.duiba.activity.center.api.dto.ActivityCategoryDto;
import cn.com.duiba.activity.center.api.dto.CategoryActivityDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteActivityCategoryBackendService <br/>
 * Function: 活动类目管理的后台接口 <br/>
 * Date:     2016年6月7日 上午8:52:18 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface RemoteActivityCategoryBackendService {
    /**
     * 创建一个活动分类
     *
     * @author xuhengfei
     * @param name
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> createCategory(String name);
    /**
     * 修改活动分类的皮肤
     *
     * @author xuhengfei
     * @param id
     * @param content
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> editCategoryContent(long id,String content);
    /**
     * 启用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> enableCategory(long id);
    /**
     * 禁用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> disableCategory(long id);
    /**
     * 查询所有的活动分类
     *
     * @author xuhengfei
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<ActivityCategoryDto>> findAll();
    /**
     * 
     * findAllActivitiesByAppCategory:查询App下某个分类的所有活动列表. <br/>
     * 
     * TODO(开发者子页面展示活动用，要求此活动兑吧与开发者均处于开启状态.).<br/>
     * TODO(当operating_activity表中的状态被置为关闭时，删除关系表数据，当置为开启时，新增关系表数据).<br/>
     * 开启需要考虑的点：计划任务推送，人为点击开启
     * 关闭需要考虑的点：管理员关闭活动，人为点击关闭
     * 
     * @author wubo
     * @param appId 应用id
     * @param categoryId 活动类目id
     * @return CategoryActivityDto
     * @since JDK 1.6
     */
    DubboResult<List<CategoryActivityDto>> findAllActivitiesByAppCategory(long appId,long categoryId);
    /**
     * 
     * sortActivitiesByAppCategory:重新设置活动列表的权重排序. <br/>
     * TODO(开发者活动子页面分类用).<br/>
     * TODO(当前子页面某个活动顺序变更时，重新分配当前子页面的所有活动权重值，并全部更新).<br/>
     *
     * @author wubo
     * @param appId
     * @param categoryId
     * @param activities
     * @return Boolean
     * @since JDK 1.6
     */
    DubboResult<Boolean> sortActivitiesByAppCategory(long appId,long categoryId,List<CategoryActivityDto> activities);
}
